# coding: utf8

from require.python import install_python
import os


if __name__ == '__main__':
    install_python('3.5.1')
    os.system('pip3 install python-stack')
